#include <stdio.h>
#include "LEPC.h"

// ********************************************************
// ** CallBack
// ********************************************************
void CallBackFunc(void *Buf, int datasize)
{
	int i;
	LE_MONDATAFORMAT2 *data = (LE_MONDATAFORMAT2 *)Buf;
	for( i = 0; i < datasize/(int)sizeof(LE_MONDATAFORMAT2); i ++ ){
		// time
		if( (data[i].framestatus & 0x3) == LE_MONSTATUS_IDLETIME ){
			printf("IDLE: %d ms\n", data[i].time.l+data[i].time.m*0x100+data[i].time.h*0x10000 );
		}
		if( (data[i].framestatus & 0x3) == LE_MONSTATUS_SD_TIMESTAMP ){
			printf("SD:TMSP: %d min %d sec %d ms \n", data[i].time.h, data[i].time.m, data[i].time.l*10 );
		}
		if( (data[i].framestatus & 0x3) == LE_MONSTATUS_RD_TIMESTAMP ){
			printf("RD:TMSP: %d min %d sec %d ms \n", data[i].time.h, data[i].time.m, data[i].time.l*10 );
		}

		// data
		if( data[i].framestatus & LE_MONSTATUS_SD_DATA_VISIBLE || data[i].framestatus & LE_MONSTATUS_RD_DATA_VISIBLE ){
			printf("SD: ");
			if( data[i].framestatus & LE_MONSTATUS_SD_DATA_VISIBLE ){
				printf("%02x ", data[i].data.SD );
			} else {
				printf("-- ");
			}

			printf("RD: ");
			if( data[i].framestatus & LE_MONSTATUS_RD_DATA_VISIBLE ){
				printf("%02x ", data[i].data.RD );
			} else {
				printf("-- ");
			}

			if( data[i].framestatus & LE_MONSTATUS_SD_DATA_VISIBLE || data[i].framestatus & LE_MONSTATUS_RD_DATA_VISIBLE ){
				printf("\n");
			}
		}
	}
}

// ********************************************************
// ** Set Parameter
// ********************************************************
int IdleTimeRec(int flag)
{
	if( flag ){
		if( LESetIdleTimeRec(LE_IDLETIMEREC_1ms) == LE_FAIL ) 	{
			printf("LESetIdleTimeRec failed\n");
			return -1;
		}
		printf("LESetIdleTimeRec 1ms\n");
	} else {
		if( LESetIdleTimeRec(LE_IDLETIMEREC_OFF) == LE_FAIL ) 	{
			printf("LESetIdleTimeRec failed\n");
			return -1;
		}
		printf("LESetIdleTimeRec off\n");
	}
	return 0;
}

int TimeStampRec(int flag)
{
	if( flag ){
		if( LESetTimeStampRec(LE_TIMESTAMPREC_MS10ms) == LE_FAIL ) 	{
			printf("LESetTimeStampRec failed\n");
			return -1;
		}
		printf("LESetTimeStampRec ms10ms\n");
	} else {
		if( LESetTimeStampRec(LE_TIMESTAMPREC_OFF) == LE_FAIL ) 	{
			printf("LESetTimeStampRec failed\n");
			return -1;
		}
		printf("LESetTimeStampRec off\n");
	}
	return 0;
}

int Protocol(int protocol)
{
	const char *protocolname[] = {
		"ASYNC","SYNC","HDLC","PPP","IRDA","I2C","BURST","","","","SPI"
	};
	if( LESetProtocol(protocol) == LE_FAIL ) 	{
		printf("LESetProtocol failed\n");
		return -1;
	}
	printf("LESetProtocol %s\n",protocolname[protocol]);
	return 0;
}

int Table(int flag)
{
	LE_LTABLE tbl;
	unsigned char uc;
	tbl.length = 0;
	if( flag ){
		for( uc = 'A'; uc <= 'Z'; uc ++ ){
			tbl.character[tbl.length] = uc;
			tbl.flag[tbl.length]  = 0;
			tbl.length ++;
		}
	} else {
		for( uc = 'a'; uc <= 'z'; uc ++ ){
			tbl.character[tbl.length] = uc;
			tbl.flag[tbl.length]  = 0;
			tbl.length ++;
		}
	}
	if( LESetTable(0, tbl) == LE_FAIL ){
		printf("LESetTable failed\n");
		return -1;
	}
	printf("LESetTable success\n");
	return 0;
}

int Start()
{
	if( LEStartManualCallBack(CallBackFunc, 2, 0, 0, 0) == LE_FAIL ){
		return -1;
		printf("LEStartManualCallBack failed\n");
	}
	printf("LEStartManualCallBack success\n");
	return 0;
}

int Stop()
{
	LEStop();
	printf("LEStop\n");
	return 0;
}

int EmuKey(int key)
{
	LEEmulationKey(key);
	printf("LEEmulationKey\n");
	return 0;
}

// ********************************************************
// ** Sample
// ********************************************************
void printmessage()
{
	printf("\n");
	printf("--------------------\n");
	printf("0:Exit\n");
	printf("1:Start\n");
	printf("2:Stop\n");
	printf("3:EmulationKey\n");
	printf("4:SetTable a-z\n");
	printf("5:SetTable A-Z\n");
	printf("6:IdleTimeRec on\n");
	printf("7:IdleTimeRec off\n");
	printf("8:TimeStampRec on\n");
	printf("9:TimeStampRec off\n");
	printf("--------------------\n");
}

int main(int argc, char *argv[])
{
	int i;

	if( argc != 2 ){
		printf("usage : LEPC_sample <serial number>\n");
		return 0;
	}

	// connect
	if( LEConnect(argv[1]) == LE_FAIL ) 	{
		printf("LEConnect failed\n");
		return -1;
	}
	printf("LEConnect %s\n",argv[1]);

	printmessage();
	while((i = getchar()) != EOF){
		if(i=='0'){
			break;
		}
		switch(i){
		case '1':	Start();
					break;
		case '2':	Stop();
					break;
		case '3':	EmuKey(LE_REMOTE_KEY_0);
					break;
		case '4':	Table(0);
					break;
		case '5':	Table(1);
					break;
		case '6':	IdleTimeRec(1);
					break;
		case '7':	IdleTimeRec(0);
					break;
		case '8':	TimeStampRec(1);
					break;
		case '9':	TimeStampRec(0);
					break;
		default:	printmessage();
					break;
		}
	}

	LEDisconnect();
	return 0;
}
